@@ -6,7 +6,7 @@
 # pieces and putting each of them onto a paper size that can be printed
 # normally. The result can then be glued together into a bigger poster.
 #
-# Copyright (C) 2019 Johannes 'josch' Schauer
+# Copyright (C) 2019 - 2021 Johannes Schauer Marin Rodrigues <josch@mister-muffin.de>
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU General Public License version 3 as published by the
@@ -46,7 +46,7 @@ except ImportError:
     tkinter.Menubutton = dummy
     tkinter.LabelFrame = dummy
 
-VERSION = "0.4"
+VERSION = "0.5"
 
 PAGE_SIZES = OrderedDict(
     [
@@ -369,6 +369,10 @@ class Plakativ:
         printable_height = self.layout["output_pagesize"][1] - (
             border_top + border_bottom
         )
+        # these may fail with "RuntimeError: image is too wide"
+        # from pdf_load_image_imp() in pdf-image.c from mupdf for sizes larger
+        # than 1<<16 pixels:
+        # https://bugs.ghostscript.com/show_bug.cgi?id=703839
         inpage_width = pt_to_mm(self.doc[self.pagenr].getDisplayList().rect.width)
         inpage_height = pt_to_mm(self.doc[self.pagenr].getDisplayList().rect.height)
 
@@ -879,7 +883,7 @@ class VerticalScrolledFrame(tkinter.Frame):
             borderwidth=0,
             highlightthickness=0,
             yscrollcommand=vscrollbar.set,
-            width=240,
+            width=240 * parent.winfo_fpixels("1i") / 96.0,
         )
         canvas.pack(side=tkinter.LEFT, fill=tkinter.BOTH, expand=tkinter.TRUE)
         vscrollbar.config(command=canvas.yview)
@@ -2202,7 +2206,7 @@ you can instruct plakativ to remove the alpha channel for you with the
 
     $ plakativ --size A1 --output=poster.pdf --remove-alpha input.png
 
-Written by Johannes 'josch' Schauer <josch@mister-muffin.de>
+Written by Johannes Schauer Marin Rodrigues <josch@mister-muffin.de>
 
 Report bugs at https://gitlab.mister-muffin.de/josch/plakativ/issues
 """
